==> DATA_H_V1.9.8.3.zip: H_9U/H_9U/models/syncdataname.py <==
"""
Created on 2019年6月28日
@author: 刘益宗
同步数据相关常量
"""


class SyncDataName:
    """
    同步数据名称
    """
    Video_Status = "main/videoStatus"
    Nomark_Data = 'main/nomarkData'
    LanguageMode = 'main/writeLanguageMode'

    Screen_Read_All_List = 'screen/readAllList'
    Screen_Ftb = 'screen/ftb'
    Screen_Write_Freeze = 'screen/writeFreeze'
    Screen_Write_OSD = 'screen/writeOSD'
    Screen_Write_BKG = 'screen/writeBKG'
    Screen_Write_Lock = 'screen/writeLock'
    Screen_Brightness = 'screen/writeBrightness'
    Screen_Delete = 'screen/deleteScreen'
    Screen_Create = 'screen/createScreen'
    Screen_Write_General = 'screen/writeGeneral'
    Screen_Write_Mode_Source = 'screen/writeModeSource'
    Screen_Write_TestPattern = 'screen/writeTestPattern'
    Screen_Write_Gamma = 'screen/writeGamma'
    Screen_Write_ImageQuality = 'screen/writeImageQuality'
    Screen_Write_HDR = 'screen/writeHDR'
    Screen_Write_3D = 'screen/write3D'
    Screen_Write_Phase_Offset = 'screen/writeScreenGenlockPhaseOffset'
    Screen_Layer_List = 'screen/readLayerList'
    Screen_Write_Attribute = 'screen/writeScreenAttribute'
    Screen_Clear_data = 'screen/clear'
    Screen_Add_Template = 'screen/addTemplate'
    Screen_Update_Template = 'screen/updateTemplate'
    Screen_Delete_Template = 'screen/deleteTemplate'
    Screen_Detail = 'screen/detail'
    Screen_Write_Volume = 'screen/writeVolume'



    Screen_Audio_Changed = 'screen/audioChanged'
    Screen_Bright_Adj_Settings = 'screen/brightAdjSettings'
    Screen_Write_Audio = 'screen/writeAudio'
    Screen_Write_Output_Channel = 'screen/outputChannel'
    Screen_Write_Output_Mode = 'screen/outputMode'


    Bkg_Read_All_List = 'bkg/readAllList'
    Bkg_Read_Detail = 'bkg/readDetail'
    Bkg_Delete = 'bkg/delete'
    Bkg_Rename = 'bkg/rename'

    Layer_Write_Window = 'layer/writeWindow'
    Layer_Write_General = 'layer/writeGeneral'
    Layer_Create = 'layer/create'
    Layer_Delete = 'layer/delete'
    Layer_Delete_All = 'layer/deleteBatch'
    Layer_Write_Z_Index = 'layer/writeZIndex'
    Layer_Write_Source = 'layer/writeSource'
    Layer_Write_Lock = 'layer/writeLock'
    Layer_Screen_Take = 'layer/screenLayerTake'
    Layer_Freeze = 'layer/freeze'
    Layer_Screen_Layout = 'layer/screenLayerLayout'
    Layer_Write_Audio_Status = 'layer/audioStatus'
    Layer_Write_Lock_Ratio = 'layer/writeLayerLockRatio'

    Input_Read_List = 'input/readList'
    Input_Read_Detail = 'input/readDetail'
    Input_IPC_Mode = 'device/writeIPCMode'
    Input_IPC_Source_Delete = 'input/IPCSourceDelete'
    Input_IPC_Source_Create = 'ipc/IPCSourceCreate'
    Input_IPC_Source_Rename = 'ipc/IPCSourceRename'
    Input_IPC_Source_Edit = 'ipc/IPCSourceEdit'
    Input_IPC_Source_Refresh = 'ipc/IPCSourceRefresh'

    Input_IPC_Channel_Add = 'ipc/IPCChannelAdd'
    Input_IPC_Channel_Edit = 'ipc/IPCChannelEdit'
    Input_IPC_Channel_Delete = 'ipc/IPCChannelDelete'

    Input_IPC_GROUP_CREATE = 'ipc/IPCGroupCreate'
    Input_IPC_GROUP_UPDATE = 'ipc/IPCGroupUpdate'
    Input_IPC_GROUP_DELETE = 'ipc/IPCGroupDelete'
    Input_IPC_GROUP_NODE_DELETE = 'ipc/IPCGroupNodeDelete'

    Input_IPC_Montage_List = 'ipc/IPCMontageList'
    Input_IPC_Montage_Save = 'ipc/IPCMontageSave'
    Input_IPC_Montage_Rename = 'ipc/IPCMontageRename'
    Input_IPC_Montage_Template_Delete = 'ipc/IPCMontageTemplateDelete'
    Input_IPC_Montage_Template_Apply = 'ipc/IPCMontageTemplateApply'
    Input_IPC_Slot_Montage_List = 'ipc/IPCSlotMontageList'
    Input_IPC_Montage_Edit = 'ipc/IPCMontageEdit'
    Input_IPC_IsOnline_Status = 'ipc/IPCOnlineStatus'
    Input_IPC_Source_Change = 'ipc/IPCSourceChange'

    Input_Group_Data = 'input/groupData'
    Input_Group_List = 'input/groupList'
    Input_Group_Delete = 'input/groupDelete'
    Input_Group_Node_Delete = 'input/groupNodeDelete'
    Input_Backup_Switch = 'input/backupSwitch'
    Input_Backup_Update = 'input/backupUpdate'
    Input_Backup_Delete = 'input/backupDelete'
    Input_Crop_Delete = 'input/deleteCrop'
    Input_Crop_Update = 'input/updateCrop'
    Input_Crop_Create = 'input/writeCrop'
    Input_Write_General = 'input/writeGeneral'
    Input_Write_MosaicMontage = 'input/saveMosaicMontag'
    Input_Mosaic_Rename = 'input/mosaicRename'

    Preset_Read_List = 'preset/readList'
    Preset_Add = 'preset/add'
    Preset_Over_Write = 'preset/overWrite'
    Preset_Delete = 'preset/deletePreset'
    Preset_Write_General = 'preset/writeGeneral'
    Preset_Play = 'preset/play'
    Preset_Group_List = 'preset/groupList'
    Preset_Poll = 'preset/readPresetPoll'
    Preset_Poll_Play = 'preset/pollPlay'
    Preset_Effect = 'preset/writeEffect'
    Preset_Show_Id = 'preset/writeShowId'
    Preset_Clear = 'preset/clear'
    Preset_Group_Clear = 'preset/groupClear'
    Preset_Group_Write_General = 'preset/writeGroupGeneral'
    Preset_Group_Add= 'preset/groupAdd'
    Preset_Group_Delete = 'preset/groupDelete'
    Preset_Group_Update = 'preset/groupUpdate'

    Device_Read_Detail = 'device/readDetail'
    Device_Read_Slot = 'device/readSlot'
    Device_Write_Genlock = 'device/writeGenlock'
    Device_Shutdown = 'device/shutdown'
    Device_Write_Com = 'device/writeCom'
    Device_Font_List = 'device/fontList'
    Device_Read_GenLock = 'device/readGenLock'
    Device_Write_Http = 'device/writeHttp'
    Device_Font_Delete = 'device/fontDelete'
    Device_Mode_Update = 'device/modeUpdate'
    Device_Central_Cmd_Create = 'device/centralCmdCreate'
    Device_Central_Cmd_DeleteBatch = 'device/centralCmdDeleteBatch'
    Device_Central_Cmd_Modify = 'device/centralCmdModify'
    Device_Audio_Attribute = 'device/audioAttribute'
    Device_Audio_List = 'device/audioList'
    Device_Read_Audio_Detail = 'device/readAudioDetail'
    Device_Read_GenLock_Status = 'device/readGenLockStatus'
    Device_Write_Port_Mode = 'device/writePortMode'
    Device_Write_Lcd_config = 'device/writeLcdConfig'
    Device_Write_Bright = 'device/writeBright'
    Device_Lcd_config = 'device/LcdConfig'


    Output_Read_List = 'output/readList'
    Output_Timing_Changed = 'output/timingChanged'
    Output_Write_General = 'output/writeGeneral'
    Output_Write_Test_Pattern = 'output/writeTestPattern'
    Output_Write_Image_Quality = 'output/writeImageQuality'
    Output_Write_Gamma = 'output/writeGamma'
    Output_EthDistance = 'device/writeOutputEthDistance'

    MVR_Window_Read_All_Info = 'mvrWindow/readAllInfo'
    MVR_Window_Create = 'mvrWindow/create'
    MVR_Window_Delete = 'mvrWindow/delete'
    MVR_Window_Delete_Batch = 'mvrWindow/deleteBatch'
    MVR_Window_Write_General = 'mvrWindow/writeGeneral'
    MVR_Window_Read_All = 'mvrWindow/readAll'
    MVR_Window_Write_Source = 'mvrWindow/writeSource'

    Device_Upgrade_Status = 'device/upgradeStatus'
    Device_Write_IP = 'device/writeIp'
    Device_Write_IP_Error = 'device/writeIpError'
    Device_Write_IPCMode = 'device/writeIPCMode'
    Device_Write_FiberMode = 'device/writeFiberMode'
    Device_Slot_VideoStreamChanged = 'device/videoStreamChanged'

    User_Read_All = 'user/all'
    User_Add = 'user/add'
    User_Delete = 'user/delete'
    User_Update = 'user/update'
    Open_Info_Add = 'open/info/add'
    Open_Info_Update = 'open/info/update'
    Open_Info_Delete = 'open/info/delete'
    Role_Read_All = 'user/all'
    Role_Add = 'role/add'
    Role_Delete = 'role/delete'
    Role_Update = 'role/update'
    Role_Change = 'role/change'

    NetWork_Group_Create = 'network/createGroup'
    NetWork_Group_Update = 'network/updateGroup'
    NetWork_Group_Delete = 'network/deleteGroup'
    NetWork_Group_Create_Node = 'network/createGroupNode'
    NetWork_Group_Delete_Node = 'network/deleteGroupNode'
    NetWork_Group_Clear_Node = 'network/clearGroupNode'
    Ndi_Source_Create = 'ndi/create'
    Ndi_Source_Update = 'ndi/update'
    Ndi_Source_Delete = 'ndi/delete'
    Ndi_Source_List = 'ndi/list'
    Ndi_Crop_Delete = 'ndi/deleteCrop'
    Ndi_Crop_Update = 'ndi/updateCrop'
    Ndi_Crop_Create = 'ndi/createCrop'
    Ndi_Source_Change = 'ndi/NdiSourceChange'






class SyncDataOptType:
    """
    同步数据操作类型
    """
    Create = 'create'
    Update = 'update'
    Delete = 'delete'
    Retrieve = 'Retrieve'

==> DATA_H_V1.9.9.2.zip: H_9U/H_9U/models/syncdataname.py <==
"""
Created on 2019年6月28日
@author: 刘益宗
同步数据相关常量
"""


class SyncDataName:
    """
    同步数据名称
    """
    Video_Status = "main/videoStatus"
    Nomark_Data = 'main/nomarkData'
    LanguageMode = 'main/writeLanguageMode'

    Screen_Read_All_List = 'screen/readAllList'
    Screen_Ftb = 'screen/ftb'
    Screen_Write_Freeze = 'screen/writeFreeze'
    Screen_Write_OSD = 'screen/writeOSD'
    Screen_Write_BKG = 'screen/writeBKG'
    Screen_Write_Lock = 'screen/writeLock'
    Screen_Brightness = 'screen/writeBrightness'
    Screen_Brightness_Multi = 'screen/multiWriteBrightness'
    Screen_Delete = 'screen/deleteScreen'
    Screen_Create = 'screen/createScreen'
    Screen_Write_General = 'screen/writeGeneral'
    Screen_Write_Mode_Source = 'screen/writeModeSource'
    Screen_Write_TestPattern = 'screen/writeTestPattern'
    Screen_Write_Gamma = 'screen/writeGamma'
    Screen_Write_ImageQuality = 'screen/writeImageQuality'
    Screen_Write_HDR = 'screen/writeHDR'
    Screen_Write_3D = 'screen/write3D'
    Screen_Write_Phase_Offset = 'screen/writeScreenGenlockPhaseOffset'
    Screen_Layer_List = 'screen/readLayerList'
    Screen_Write_Attribute = 'screen/writeScreenAttribute'
    Screen_Clear_data = 'screen/clear'
    Screen_Add_Template = 'screen/addTemplate'
    Screen_Update_Template = 'screen/updateTemplate'
    Screen_Delete_Template = 'screen/deleteTemplate'
    Screen_Detail = 'screen/detail'
    Screen_Write_Volume = 'screen/writeVolume'
    Screen_Weather_Changed = "screen/weatherChanged"



    Screen_Audio_Changed = 'screen/audioChanged'
    Screen_Bright_Adj_Settings = 'screen/brightAdjSettings'
    Screen_Write_Audio = 'screen/writeAudio'
    Screen_Write_Output_Channel = 'screen/outputChannel'
    Screen_Write_Output_Mode = 'screen/outputMode'
    Screen_Write_DynamicSubpixel = 'screen/dynamicSubpixel'


    Bkg_Read_All_List = 'bkg/readAllList'
    Bkg_Read_Detail = 'bkg/readDetail'
    Bkg_Delete = 'bkg/delete'
    Bkg_Rename = 'bkg/rename'

    Layer_Write_Window = 'layer/writeWindow'
    Layer_Write_General = 'layer/writeGeneral'
    Layer_Create = 'layer/create'
    Layer_Delete = 'layer/delete'
    Layer_Delete_All = 'layer/deleteBatch'
    Layer_Write_Z_Index = 'layer/writeZIndex'
    Layer_Write_Source = 'layer/writeSource'
    Layer_Write_Lock = 'layer/writeLock'
    Layer_Screen_Take = 'layer/screenLayerTake'
    Layer_Freeze = 'layer/freeze'
    Layer_Screen_Layout = 'layer/screenLayerLayout'
    Layer_Write_Audio_Status = 'layer/audioStatus'
    Layer_Write_Lock_Ratio = 'layer/writeLayerLockRatio'
    Layer_Exceed_Limit = 'layer/exceedLimit'
    Layer_Write_Stream_Rule  = 'layer/writeStreamRule'


    Input_Read_List = 'input/readList'
    Input_Read_Detail = 'input/readDetail'
    Input_IPC_Mode = 'device/writeIPCMode'
    Input_IPC_Source_Delete = 'input/IPCSourceDelete'
    Input_IPC_Source_Create = 'ipc/IPCSourceCreate'
    Input_IPC_Source_Rename = 'ipc/IPCSourceRename'
    Input_IPC_Source_Edit = 'ipc/IPCSourceEdit'
    Input_IPC_Source_Refresh = 'ipc/IPCSourceRefresh'

    Input_IPC_Channel_Add = 'ipc/IPCChannelAdd'
    Input_IPC_Channel_Edit = 'ipc/IPCChannelEdit'
    Input_IPC_Channel_Delete = 'ipc/IPCChannelDelete'

    Input_IPC_GROUP_CREATE = 'ipc/IPCGroupCreate'
    Input_IPC_GROUP_UPDATE = 'ipc/IPCGroupUpdate'
    Input_IPC_GROUP_DELETE = 'ipc/IPCGroupDelete'
    Input_IPC_GROUP_NODE_DELETE = 'ipc/IPCGroupNodeDelete'

    Input_IPC_Crop_Delete = 'input/IPCDeleteCrop'
    Input_IPC_Crop_Update = 'input/IPCUpdateCrop'
    Input_IPC_Crop_Create = 'input/IPCWriteCrop'

    Input_IPC_Montage_List = 'ipc/IPCMontageList'
    Input_IPC_Montage_Save = 'ipc/IPCMontageSave'
    Input_IPC_Montage_Rename = 'ipc/IPCMontageRename'
    Input_IPC_Montage_Template_Delete = 'ipc/IPCMontageTemplateDelete'
    Input_IPC_Montage_Template_Apply = 'ipc/IPCMontageTemplateApply'
    Input_IPC_Slot_Montage_List = 'ipc/IPCSlotMontageList'
    Input_IPC_Montage_Edit = 'ipc/IPCMontageEdit'
    Input_IPC_IsOnline_Status = 'ipc/IPCOnlineStatus'
    Input_IPC_Source_Change = 'ipc/IPCSourceChange'
    Input_IPC_Bg_Color = 'ipc/writeIPCBgColor'
    Input_IPC_Stream_Rule = 'ipc/writeStreamRule'
    Input_IPC_Montage_Zorder_Edit = 'ipc/IPCMontageZorderEdit'
    Input_IPC_Montage_Group_Update = 'ipc/IPCMontageGroupUpdate'
    Input_IPC_Montage_Poll_Status = 'ipc/IPCMontagePollStatus'

    Input_Group_Data = 'input/groupData'
    Input_Group_List = 'input/groupList'
    Input_Group_Delete = 'input/groupDelete'
    Input_Group_Node_Delete = 'input/groupNodeDelete'
    Input_Backup_Switch = 'input/backupSwitch'
    Input_Backup_Update = 'input/backupUpdate'
    Input_Backup_Delete = 'input/backupDelete'
    Input_Crop_Delete = 'input/deleteCrop'
    Input_Crop_Update = 'input/updateCrop'
    Input_Crop_Create = 'input/writeCrop'
    Input_Write_General = 'input/writeGeneral'
    Input_Write_MosaicMontage = 'input/saveMosaicMontag'
    Input_Mosaic_Rename = 'input/mosaicRename'

    Input_Source_Create = 'input/createSource'
    Input_Source_Delete = 'input/deleteSource'
    Input_Source_Update = 'input/updateSource'
    Input_Source_List_Enable   = 'input/enableSourceList'
    Input_Source_Training_Sort = 'input/readTrainingSort'
    Input_Source_IsUsed = 'input/sourceIsUsed'
    Input_SubSourceList = 'input/subSourceList'
    Notime_Source_Changed = 'input/notimeSourceChanged'

    Preset_Read_List = 'preset/readList'
    Preset_Add = 'preset/add'
    Preset_Over_Write = 'preset/overWrite'
    Preset_Delete = 'preset/deletePreset'
    Preset_Write_General = 'preset/writeGeneral'
    Preset_Play = 'preset/play'
    Preset_Group_List = 'preset/groupList'
    Preset_Poll = 'preset/readPresetPoll'
    Preset_Poll_Play = 'preset/pollPlay'
    Preset_Effect = 'preset/writeEffect'
    Preset_Show_Id = 'preset/writeShowId'
    Preset_Clear = 'preset/clear'
    Preset_Group_Clear = 'preset/groupClear'
    Preset_Group_Write_General = 'preset/writeGroupGeneral'
    Preset_Group_Add= 'preset/groupAdd'
    Preset_Group_Delete = 'preset/groupDelete'
    Preset_Group_Update = 'preset/groupUpdate'
    Preset_Collection_Create = 'preset/collectionCreate'
    Preset_Collection_Delete = 'preset/collectionDelete'
    Preset_Collection_DelAll = 'preset/collectionDelAll'
    Preset_Collection_Update = 'preset/collectionUpdate'
    Preset_Collection_Play   = 'preset/collectionPlay'


    Device_Read_Detail = 'device/readDetail'
    Device_Read_Slot = 'device/readSlot'
    Device_Write_Genlock = 'device/writeGenlock'
    Device_Shutdown = 'device/shutdown'
    Device_Write_Com = 'device/writeCom'
    Device_Font_List = 'device/fontList'
    Device_Read_GenLock = 'device/readGenLock'
    Device_Write_Http = 'device/writeHttp'
    Device_Font_Delete = 'device/fontDelete'
    Device_Mode_Update = 'device/modeUpdate'
    Device_Central_Cmd_Create = 'device/centralCmdCreate'
    Device_Central_Cmd_DeleteBatch = 'device/centralCmdDeleteBatch'
    Device_Central_Cmd_Modify = 'device/centralCmdModify'
    Device_Audio_Attribute = 'device/audioAttribute'
    Device_Audio_List = 'device/audioList'
    Device_Read_Audio_Detail = 'device/readAudioDetail'
    Device_Read_GenLock_Status = 'device/readGenLockStatus'
    Device_Write_Port_Mode = 'device/writePortMode'
    Device_Write_Lcd_config = 'device/writeLcdConfig'
    Device_Write_Bright = 'device/writeBright'
    Device_Lcd_config = 'device/LcdConfig'
    Device_Time_Changed = "device/deviceTimeChanged"
    Device_Test_Pattern_Border_Status = 'device/testPatternBorderStatus'


    Output_Read_List = 'output/readList'
    Output_Timing_Changed = 'output/timingChanged'
    Output_Write_General = 'output/writeGeneral'
    Output_Write_Test_Pattern = 'output/writeTestPattern'
    Output_Write_Image_Quality = 'output/writeImageQuality'
    Output_Write_Gamma = 'output/writeGamma'
    Output_EthDistance = 'device/writeOutputEthDistance'

    MVR_Window_Read_All_Info = 'mvrWindow/readAllInfo'
    MVR_Window_Create = 'mvrWindow/create'
    MVR_Window_Delete = 'mvrWindow/delete'
    MVR_Window_Delete_Batch = 'mvrWindow/deleteBatch'
    MVR_Window_Write_General = 'mvrWindow/writeGeneral'
    MVR_Window_Read_All = 'mvrWindow/readAll'
    MVR_Window_Write_Source = 'mvrWindow/writeSource'
    MVR_Window_Group_Create = 'mvrWindow/createGroup'
    MVR_Window_Group_Delete = 'mvrWindow/deleteGroup'
    MVR_Window_Group_Update = 'mvrWindow/updateGroup'
    MVR_Window_Group_Play = 'mvrWindow/groupPlay'
    MVR_Window_Group_Poll_Write = 'mvrWindow/groupPollWrite'
    MVR_Window_Group_Poll_Status = 'mvrWindow/groupPollStatus'

    Device_Upgrade_Status = 'device/upgradeStatus'
    Device_Write_IP = 'device/writeIp'
    Device_Write_IP_Error = 'device/writeIpError'
    Device_Write_IPCMode = 'device/writeIPCMode'
    Device_Write_FiberMode = 'device/writeFiberMode'
    Device_Slot_VideoStreamChanged = 'device/videoStreamChanged'
    Device_Write_DNS = 'device/writeDNS'

    User_Read_All = 'user/all'
    User_Add = 'user/add'
    User_Delete = 'user/delete'
    User_Update = 'user/update'
    Open_Info_Add = 'open/info/add'
    Open_Info_Update = 'open/info/update'
    Open_Info_Delete = 'open/info/delete'
    Role_Read_All = 'user/all'
    Role_Add = 'role/add'
    Role_Delete = 'role/delete'
    Role_Update = 'role/update'
    Role_Change = 'role/change'

    NetWork_Group_Create = 'network/createGroup'
    NetWork_Group_Update = 'network/updateGroup'
    NetWork_Group_Delete = 'network/deleteGroup'
    NetWork_Group_Create_Node = 'network/createGroupNode'
    NetWork_Group_Delete_Node = 'network/deleteGroupNode'
    NetWork_Group_Clear_Node = 'network/clearGroupNode'
    Ndi_Source_Create = 'ndi/create'
    Ndi_Source_Update = 'ndi/update'
    Ndi_Source_Delete = 'ndi/delete'
    Ndi_Source_List = 'ndi/list'
    Ndi_Crop_Delete = 'ndi/deleteCrop'
    Ndi_Crop_Update = 'ndi/updateCrop'
    Ndi_Crop_Create = 'ndi/createCrop'
    Ndi_Source_Change = 'ndi/NdiSourceChange'






class SyncDataOptType:
    """
    同步数据操作类型
    """
    Create = 'create'
    Update = 'update'
    Delete = 'delete'
    Retrieve = 'Retrieve'
